@@ -2,9 +2,10 @@
 # SPDX-License-Identifier: MPL-2.0+
 
 # Function to create augmented Vandermonde matrix for polynomial approximation.
-polyMat <- function(x, y, relErr) {
+polyMat <- function(x, y, relErr, basis) {
   n <- length(x)
-  A <- vanderMat(x, n - 2L)
+  matFunc <- switch(EXPR = basis, m = vanderMat, chebMat)
+  A <- matFunc(x, n - 2L)
   altSgn <- (-1) ^ (seq_len(n) - 1L)
   # For relative error, need to weight the E by f(x).
   if (relErr) altSgn <- altSgn * y
@@ -12,9 +13,9 @@ polyMat <- function(x, y, relErr) {
 }
 
 # Function to calculate coefficients given matrix and known values.
-polyCoeffs <- function(x, fn, relErr, l, u, zt) {
+polyCoeffs <- function(x, fn, relErr, basis, l, u, zt) {
   y <- callFun(fn, x)
-  P <- polyMat(x, y, relErr)
+  P <- polyMat(x, y, relErr, basis)
   PP <- tryCatch(solve(P, y),
                  error = function(cond) simpleError(trimws(cond$message)))
   if (inherits(PP, "simpleError")) PP <- qr.solve(P, y, tol = 1e-14)
@@ -22,7 +23,7 @@ polyCoeffs <- function(x, fn, relErr, l, u, zt) {
 }
 
 # Main function to calculate and return the minimax polynomial approximation.
-remPoly <- function(fn, lower, upper, degree, relErr, opts) {
+remPoly <- function(fn, lower, upper, degree, relErr, basis, opts) {
 
   # Set ZeroBasis relErr flag
   relErrZeroBasis <- FALSE
@@ -31,21 +32,19 @@ remPoly <- function(fn, lower, upper, degree, relErr, opts) {
   x <- chebNodes(degree + 2L, lower, upper)
 
   # Initial Polynomial Guess
-  PP <- polyCoeffs(x, fn, relErr, lower, upper, opts$ztol)
-  errs_last <- remErr(x, PP, fn, relErr)
-  converged <- FALSE
-  unchanged <- FALSE
-  unchanging_i <- 0L
-  i <- 0L
+  PP <- polyCoeffs(x, fn, relErr, basis, lower, upper, opts$ztol)
+  errs_last <- remErr(x, PP, fn, relErr, basis)
+  converged <- unchanged <- FALSE
+  unchanging_i <- i <- 0L
   repeat {
     # Check for maxiter
     if (i >= opts$maxiter) break
     i <- i + 1L
-    r <- findRoots(x, PP, fn, relErr)
-    x <- switchX(r, lower, upper, PP, fn, relErr)
+    r <- findRoots(x, PP, fn, relErr, basis)
+    x <- switchX(r, lower, upper, PP, fn, relErr, basis)
     relErrZeroBasis <- relErrZeroBasis || attr(x, "ZeroBasis")
-    PP <- polyCoeffs(x, fn, relErr, lower, upper, opts$ztol)
-    errs <- remErr(x, PP, fn, relErr)
+    PP <- polyCoeffs(x, fn, relErr, basis, lower, upper, opts$ztol)
+    errs <- remErr(x, PP, fn, relErr, basis)
     mxae <- max(abs(errs))
     expe <- abs(PP$E)
 
@@ -61,14 +60,14 @@ remPoly <- function(fn, lower, upper, degree, relErr, opts) {
 
     # Check that solution is evolving. If solution is not evolving then further
     # iterations will not help.
-    if (all(errs / errs_last <= opts$convrat) ||
-          all(abs(errs - errs_last) <= opts$tol)) {
+    if (isUnchanging(errs, errs_last, opts$convrat, opts$tol)) {
       unchanging_i <- unchanging_i + 1L
       if (unchanging_i >= opts$conviter) {
         unchanged <- TRUE
         break
       }
     }
+
     errs_last <- errs
   }
 
