@@ -10,7 +10,8 @@ opts <- list(maxiter = 100L, miniter = 10L, conviter = 10L,
 # Test polyMat
 x <- c(-0.4, 0.1, 0.3, 0.4)
 control <- matrix(c(rep(1, 4L), x, x ^ 2, 1, -1, 1, -1), nrow = 4)
-expect_identical(minimaxApprox:::polyMat(x, y = NULL, relErr = FALSE), control)
+expect_identical(minimaxApprox:::polyMat(x, y = NULL, relErr = FALSE,
+                                         basis = "m"), control)
 
 # Test polyCoeffs
 # If the function is a pure polynomial then coeffs should recover it exactly.
@@ -19,6 +20,6 @@ expect_identical(minimaxApprox:::polyMat(x, y = NULL, relErr = FALSE), control)
 fn <- function(x) x ^ 2 + 2 * x + 3
 x <- seq(0, 2, length.out = 4)
 control <- c(3, 2, 1)
-PP <- minimaxApprox:::polyCoeffs(x, fn, TRUE, 0, 2, opts$ztol)
+PP <- minimaxApprox:::polyCoeffs(x, fn, TRUE, "m", 0, 2, opts$ztol)
 expect_equal(PP$a, control, tolerance = tol)
 expect_equal(PP$E, 0, tolerance = tol)
